@@ -29,6 +29,7 @@ use Date::Manip;
 use English qw( -no_match_vars);
 use File::Basename;
 use File::Glob;
+use File::Path qw(make_path);
 use Hash::Merge qw/merge/;
 use Log::Log4perl qw(:easy);
 use Pod::Usage;
@@ -39,7 +40,7 @@ use Unicode::String;
 
 {    # BEGIN CLASS
 
-    use version; our $VERSION = qv('3.4.0.3');
+    use version; our $VERSION = qv('3.4.0.5');
     use re 'taint';    # Keep data captured by parens tainted
     delete @ENV{qw(PATH IFS CDPATH ENV BASH_ENV)};    # Make %ENV safe
 
@@ -59,6 +60,8 @@ use Unicode::String;
         ( q{.}, q{/}, 0 .. 9, 'A' .. 'Z', 'a' .. 'z' );
     Readonly::Scalar my $MODSALT_BASE => 64;
     Readonly::Scalar my $LINEWIDTH    => 78;
+    Readonly::Scalar my $STRICT_UMASK => oct 77;
+    Readonly::Scalar my $CACHE_DIR    => '/var/cache/cipux';
 
     # +======================================================================+
     # || GLOBAL                                                             ||
@@ -174,6 +177,7 @@ use Unicode::String;
     # +======================================================================+
     # || config                                                             ||
     # +======================================================================+
+    # OLD config space, will be dropped in 3.4.2.x
     sub config {
 
         # +------------------------------------------------------------------+
@@ -233,6 +237,7 @@ use Unicode::String;
     # +======================================================================+
     # || source                                                             ||
     # +======================================================================+
+    # OLD config space, will be dropped in 3.4.2.x
     sub source {
 
         # +------------------------------------------------------------------+
@@ -979,7 +984,7 @@ use Unicode::String;
 
         # +------------------------------------------------------------------+
         # | main
-        tie my @u, 'Array::Unique';
+        tie my @u, 'Array::Unique';   ## no critic (Miscellanea::ProhibitTies)
         @u = ( @{$b_ar}, @{$a_ar} );
 
         undef $b_ar;
@@ -1020,6 +1025,7 @@ use Unicode::String;
                 'HASH' => {
                     'SCALAR' => sub { $_[1] },
                     'ARRAY'  => sub { [ values %{ $_[0] }, @{ $_[1] } ] },
+                    ## no critic (Subroutines::ProtectPrivateSubs)
                     'HASH' =>
                         sub { Hash::Merge::_merge_hashes( $_[0], $_[1] ) },
                 },
@@ -1054,7 +1060,8 @@ use Unicode::String;
     # +======================================================================+
     # || cfg                                                                ||
     # +======================================================================+
-    sub cfg {
+    # NEW config space, will be used after 3.4.0.0
+    sub cfg {    ## no critic (Subroutines::ProhibitExcessComplexity)
 
         # +------------------------------------------------------------------+
         # | API
@@ -1063,6 +1070,12 @@ use Unicode::String;
         my $pkg = exists $arg_r->{pkg} ? $arg_r->{pkg} : 'cipux';
         my $sub = exists $arg_r->{sub} ? $arg_r->{sub} : $EMPTY_STRING;
         my $cfg = exists $arg_r->{cfg} ? $arg_r->{cfg} : undef;
+        my $cache_dir
+            = (exists $arg_r->{cache_dir}
+            and defined $arg_r->{cache_dir}
+            and $arg_r->{cache_dir} ne $EMPTY_STRING)
+            ? $self->l( $arg_r->{cache_dir} )
+            : $CACHE_DIR;
 
         # +------------------------------------------------------------------+
         # | prepare
@@ -1080,18 +1093,12 @@ use Unicode::String;
             ? "$pkg-$sub"
             : $pkg;
 
-        if ( not -d '/tmp/cipux' and not defined $cfg ) {
-            mkdir '/tmp/cipux', 0700 or croak "Can not crate /tmp/cipux $!";
-            chown 0, 0, '/tmp/cipux' or croak 'Can not chwon 0,0,/tmp/cipux';
-        }
-        elsif ( not defined $cfg ) {
-            chown 0, 0, '/tmp/cipux' or croak 'Can not chwon 0,0,/tmp/cipux';
-            chmod 0700, '/tmp/cipux' or croak 'Can not chmod 0700,/tmp/cipux';
-        }
-        if ( -e "/tmp/cipux/$cfgbase" and not defined $cfg ) {
-            $logger->debug("use disk: /tmp/cipux/$cfgbase");
-            my $cfg_hr = retrieve("/tmp/cipux/$cfgbase")
-                or croak "Can not load $cfgbase in /tmp/cipux/$cfgbase";
+        $self->create_cache_dir_if_not_present( { cache_dir => $cache_dir } );
+
+        if ( -e "$cache_dir/$cfgbase" and not defined $cfg ) {
+            $logger->debug("use disk: $cache_dir/$cfgbase");
+            my $cfg_hr = retrieve("$cache_dir/$cfgbase")
+                or croak "Can not load $cfgbase in $cache_dir/$cfgbase";
             return $cfg_hr;
         }
 
@@ -1161,8 +1168,8 @@ use Unicode::String;
             $merged_hr = merge( $merged_hr, $cfg_hr->{$filename} );
         }
 
-        store( $merged_hr, "/tmp/cipux/$cfgbase" )
-            or croak "Can not save $cfgbase in /tmp/cipux/$cfgbase";
+        store( $merged_hr, "$cache_dir/$cfgbase" )
+            or croak "Can not save $cfgbase in $cache_dir/$cfgbase";
 
         $logger->debug('END');
 
@@ -1172,6 +1179,47 @@ use Unicode::String;
 
     }
 
+    sub create_cache_dir_if_not_present {
+
+        my ( $self, $arg_r ) = @_;
+
+        my $cache_dir
+            = (exists $arg_r->{cache_dir}
+            and defined $arg_r->{cache_dir}
+            and $arg_r->{cache_dir} ne $EMPTY_STRING )
+            ? $self->l( $arg_r->{cache_dir} )
+            : $CACHE_DIR;
+
+        if ( not -d $cache_dir ) {
+
+            # mkdir $cache_dir
+            # or croak "Can not crate $cache_dir $!";
+            my $umask = umask;
+            umask $STRICT_UMASK;
+            make_path( $cache_dir, { error => \my $err } );
+            umask $umask;
+            if ( scalar @{$err} ) {
+                for my $diag ( @{$err} ) {
+                    my ( $file, $message ) = %{$diag};
+                    if ( $file eq $EMPTY_STRING ) {
+                        warn "general error: $message\n";
+                    }
+                    else {
+                        warn "problem createing $file: $message\n";
+                    }
+                }
+            }
+
+            # chown 0, 0, $cache_dir
+            #   or croak 'Can not chown 0,0,$cache_dir';
+            # chmod 0700, $cache_dir
+            #  or croak 'Can not chmod 0700,$cache_dir';
+        }
+
+        return;
+
+    }
+
 }    # END INSIDE-OUT CLASS
 
 1;
@@ -1189,7 +1237,7 @@ CipUX - Common CipUX functions
 
 =head1 VERSION
 
-version 3.4.0.3
+version 3.4.0.5
 
 =head1 SYNOPSIS
 
@@ -1437,6 +1485,12 @@ for this task.
    configuration file type mixture was tested. As a recommendation, you should
    not mix to many files and formats.
 
+=head2 create_cache_dir_if_not_present
+
+Creates a directory 'cipux' under /var/cache if not present. This is used to
+store serialized objects.
+
+
 =head1 DIAGNOSTICS
 
 This module generates the following exceptions:
@@ -1459,6 +1513,7 @@ Not applicable.
  English
  File::Basename
  File::Glob
+ File::Path
  Hash::Merge
  Log::Log4perl
  Pod::Usage
